CHANGELOG
=========

0.2.0 (2016-05-19)
------------------

- Update to ``kinto.core`` for compatibility with Kinto 3.0. This
  release is no longer compatible with Kinto < 3.0, please upgrade!


0.1.1 (2016-05-06)
------------------

- Missing commit in previous release.


0.1.0 (2016-05-06)
------------------

**New features**

- Supports metrics in the URL (#6)
- Add a view to render the XML Blocklists file in versions 1, 2 and 3 (#3)
